@@ -75,11 +75,16 @@ else:
     )
 
 if str is bytes:
-    from cStringIO import StringIO  # pylint: disable=I0021,import-error
-    from cStringIO import StringIO as BytesIO  # pylint: disable=I0021,import-error
+    from cStringIO import (  # pylint: disable=I0021,import-error,ungrouped-imports
+        StringIO,
+    )
+else:
+    from io import StringIO  # pylint: disable=I0021,import-error,ungrouped-imports
+
+if str is bytes:
+    BytesIO = StringIO
 else:
     from io import BytesIO  # pylint: disable=I0021,import-error
-    from io import StringIO  # pylint: disable=I0021,import-error
 
 try:
     from functools import total_ordering
