@@ -58,7 +58,7 @@ def _generateCallCodePosOnly(
         context.setCurrentSourceCodeReference(expression.getCompatibleSourceReference())
 
         if call_args is not None:
-            call_args_value = call_args.getConstant()
+            call_args_value = call_args.getCompileTimeConstant()
         else:
             call_args_value = ()
 
@@ -140,7 +140,7 @@ def _generateCallCodePosOnly(
     elif call_args.isExpressionMakeTuple():
         call_arg_names = []
 
-        for call_arg_element in call_args.getElements():
+        for call_arg_element in call_args.subnode_elements:
             call_arg_name = generateChildExpressionCode(
                 child_name=call_args.getChildName() + "_element",
                 expression=call_arg_element,
@@ -266,9 +266,7 @@ def generateCallCode(to_name, expression, emit, context):
         to_name, "call_result", expression, emit, context
     ) as result_name:
 
-        if call_kw is None or (
-            call_kw.isExpressionConstantRef() and call_kw.getConstant() == {}
-        ):
+        if call_kw is None or call_kw.isExpressionConstantDictEmptyRef():
             _generateCallCodePosOnly(
                 to_name=result_name,
                 called_name=called_name,
@@ -280,9 +278,7 @@ def generateCallCode(to_name, expression, emit, context):
         else:
             call_args = expression.getCallArgs()
 
-            if call_args is None or (
-                call_args.isExpressionConstantRef() and call_args.getConstant() == ()
-            ):
+            if call_args is None or call_args.isExpressionConstantTupleEmptyRef():
                 _generateCallCodeKwOnly(
                     to_name=result_name,
                     called_name=called_name,
@@ -361,28 +357,37 @@ def _getInstanceCallCodePosArgsQuick(
     to_name, called_name, called_attribute_name, arg_names, needs_check, emit, context
 ):
     arg_size = len(arg_names)
-    quick_instance_calls_used.add(arg_size)
 
     # For 0 arguments, NOARGS is supposed to be used.
     assert arg_size > 0
 
     emitLineNumberUpdateCode(emit, context)
 
-    emit(
-        """\
+    # For one argument, we have a dedicated helper function that might
+    # be more efficient.
+    if arg_size == 1:
+        emit(
+            """%s = CALL_METHOD_WITH_SINGLE_ARG(%s, %s, %s);"""
+            % (to_name, called_name, called_attribute_name, arg_names[0])
+        )
+    else:
+        quick_instance_calls_used.add(arg_size)
+
+        emit(
+            """\
 {
     PyObject *call_args[] = {%s};
     %s = CALL_METHOD_WITH_ARGS%d(%s, %s, call_args);
 }
 """
-        % (
-            ", ".join(str(arg_name) for arg_name in arg_names),
-            to_name,
-            arg_size,
-            called_name,
-            called_attribute_name,
+            % (
+                ", ".join(str(arg_name) for arg_name in arg_names),
+                to_name,
+                arg_size,
+                called_name,
+                called_attribute_name,
+            )
         )
-    )
 
     getErrorExitCode(
         check_name=to_name,
