@@ -20,7 +20,7 @@
 """
 
 
-from nuitka.codegen.ErrorCodes import getCheckObjectCode, getErrorExitBoolCode
+from nuitka.codegen.ErrorCodes import getErrorExitBoolCode
 from nuitka.codegen.templates.CodeTemplatesVariables import (
     template_del_local_intolerant,
     template_del_local_known,
@@ -28,8 +28,8 @@ from nuitka.codegen.templates.CodeTemplatesVariables import (
     template_del_shared_intolerant,
     template_del_shared_known,
     template_del_shared_tolerant,
-    template_release_clear,
-    template_release_unclear,
+    template_release_object_clear,
+    template_release_object_unclear,
     template_write_local_clear_ref0,
     template_write_local_clear_ref1,
     template_write_local_empty_ref0,
@@ -94,25 +94,17 @@ class CPythonPyObjectPtrBase(CTypeBase):
         return "CHECK_IF_TRUE(%s)" % value_name
 
     @classmethod
-    def emitTruthCheckCode(cls, to_name, value_name, needs_check, emit, context):
+    def emitTruthCheckCode(cls, to_name, value_name, emit):
         emit("%s = CHECK_IF_TRUE(%s);" % (to_name, value_name))
 
-        if needs_check:
-            getErrorExitBoolCode(
-                condition="%s == -1" % to_name,
-                needs_check=needs_check,
-                emit=emit,
-                context=context,
-            )
-
     @classmethod
-    def getReleaseCode(cls, variable_code_name, needs_check, emit):
+    def getReleaseCode(cls, value_name, needs_check, emit):
         if needs_check:
-            template = template_release_unclear
+            template = template_release_object_unclear
         else:
-            template = template_release_clear
+            template = template_release_object_clear
 
-        emit(template % {"identifier": variable_code_name})
+        emit(template % {"identifier": value_name})
 
     @classmethod
     def emitAssignmentCodeFromBoolCondition(cls, to_name, condition, emit):
@@ -154,6 +146,14 @@ class CTypePyObjectPtr(CPythonPyObjectPtrBase):
         else:
             return init_from
 
+    @classmethod
+    def getInitTestConditionCode(cls, value_name, inverted):
+        return "%s %s NULL" % (value_name, "==" if inverted else "!=")
+
+    @classmethod
+    def emitReinitCode(cls, value_name, emit):
+        emit("%s = NULL;" % value_name)
+
     @classmethod
     def getVariableArgDeclarationCode(cls, variable_code_name):
         return "PyObject *%s" % variable_code_name
@@ -162,13 +162,9 @@ class CTypePyObjectPtr(CPythonPyObjectPtrBase):
     def getVariableArgReferencePassingCode(cls, variable_code_name):
         return "&%s" % variable_code_name
 
-    @classmethod
-    def getLocalVariableInitTestCode(cls, value_name, inverted):
-        return "%s %s NULL" % (value_name, "==" if inverted else "!=")
-
     @classmethod
     def getCellObjectAssignmentCode(cls, target_cell_code, variable_code_name, emit):
-        emit("%s = PyCell_NEW0(%s);" % (target_cell_code, variable_code_name))
+        emit("%s = Nuitka_Cell_New0(%s);" % (target_cell_code, variable_code_name))
 
     @classmethod
     def getDeleteObjectCode(
@@ -197,9 +193,8 @@ class CTypePyObjectPtr(CPythonPyObjectPtrBase):
         return value_name
 
     @classmethod
-    def emitValueAssertionCode(cls, value_name, emit, context):
-        # Not using the context, pylint: disable=unused-argument
-        getCheckObjectCode(check_name=value_name, emit=emit)
+    def emitValueAssertionCode(cls, value_name, emit):
+        emit("CHECK_OBJECT(%s);" % value_name)
 
     @classmethod
     def emitAssignConversionCode(cls, to_name, value_name, needs_check, emit, context):
@@ -223,10 +218,29 @@ class CTypePyObjectPtr(CPythonPyObjectPtrBase):
     def getExceptionCheckCondition(cls, value_name):
         return "%s == NULL" % value_name
 
+    @classmethod
+    def getReleaseCode(cls, value_name, needs_check, emit):
+        if needs_check:
+            template = template_release_object_unclear
+        else:
+            template = template_release_object_clear
+
+        emit(template % {"identifier": value_name})
+
+    @classmethod
+    def getTakeReferenceCode(cls, value_name, emit):
+        """Take reference code for given object."""
+
+        emit("Py_INCREF(%s);" % value_name)
+
 
 class CTypePyObjectPtrPtr(CPythonPyObjectPtrBase):
     c_type = "PyObject **"
 
+    @classmethod
+    def getInitTestConditionCode(cls, value_name, inverted):
+        return "*%s %s NULL" % (value_name, "==" if inverted else "!=")
+
     @classmethod
     def getVariableArgDeclarationCode(cls, variable_code_name):
         return "PyObject **%s" % variable_code_name
@@ -243,10 +257,6 @@ class CTypePyObjectPtrPtr(CPythonPyObjectPtrBase):
         # Use the object pointed to.
         return VariableDeclaration("PyObject *", "*%s" % value_name, None, None)
 
-    @classmethod
-    def getLocalVariableInitTestCode(cls, value_name, inverted):
-        return "*%s %s NULL" % (value_name, "==" if inverted else "!=")
-
     @classmethod
     def emitAssignmentCodeFromBoolCondition(cls, to_name, condition, emit):
         emit(
@@ -263,9 +273,13 @@ class CTypeCellObject(CTypeBase):
         # TODO: Single out "init_from" only user, so it becomes sure that we
         # get a reference transferred here in these cases.
         if init_from is not None:
-            return "PyCell_NEW1(%s)" % init_from
+            return "Nuitka_Cell_New1(%s)" % init_from
         else:
-            return "PyCell_EMPTY()"
+            return "Nuitka_Cell_Empty()"
+
+    @classmethod
+    def getInitTestConditionCode(cls, value_name, inverted):
+        return "%s->ob_ref %s NULL" % (value_name, "==" if inverted else "!=")
 
     @classmethod
     def getCellObjectAssignmentCode(cls, target_cell_code, variable_code_name, emit):
@@ -304,7 +318,7 @@ class CTypeCellObject(CTypeBase):
 
         # Use the object pointed to.
         return VariableDeclaration(
-            "PyObject *", "PyCell_GET(%s)" % value_name, None, None
+            "PyObject *", "Nuitka_Cell_GET(%s)" % value_name, None, None
         )
 
     @classmethod
@@ -315,10 +329,6 @@ class CTypeCellObject(CTypeBase):
     def getVariableArgReferencePassingCode(cls, variable_code_name):
         return variable_code_name
 
-    @classmethod
-    def getLocalVariableInitTestCode(cls, value_name, inverted):
-        return "%s->ob_ref %s NULL" % (value_name, "==" if inverted else "!=")
-
     @classmethod
     def emitAssignmentCodeFromBoolCondition(cls, to_name, condition, emit):
         emit(
@@ -341,10 +351,22 @@ class CTypeCellObject(CTypeBase):
             )
 
     @classmethod
-    def getReleaseCode(cls, variable_code_name, needs_check, emit):
+    def getReleaseCode(cls, value_name, needs_check, emit):
         if needs_check:
-            template = template_release_unclear
+            template = template_release_object_unclear
         else:
-            template = template_release_clear
+            template = template_release_object_clear
 
-        emit(template % {"identifier": variable_code_name})
+        emit(template % {"identifier": value_name})
+
+    @classmethod
+    def emitReinitCode(cls, value_name, emit):
+        emit("%s = NULL;" % value_name)
+
+    @classmethod
+    def emitValueAssertionCode(cls, value_name, emit):
+        emit("CHECK_OBJECT(%s->ob_ref);" % value_name)
+
+    @classmethod
+    def emitReleaseAssertionCode(cls, value_name, emit):
+        emit("CHECK_OBJECT(%s);" % value_name)
