@@ -28,12 +28,12 @@ import hashlib
 import inspect
 import marshal
 import os
+import pkgutil
 import shutil
 import subprocess
 import sys
-from logging import debug, info, warning
 
-from nuitka import Options, SourceCodeReferences, Tracing
+from nuitka import Options, SourceCodeReferences
 from nuitka.__past__ import iterItems
 from nuitka.containers.odict import OrderedDict
 from nuitka.containers.oset import OrderedSet
@@ -48,6 +48,7 @@ from nuitka.nodes.ModuleNodes import (
 )
 from nuitka.plugins.Plugins import Plugins
 from nuitka.PythonVersions import python_version
+from nuitka.Tracing import general, inclusion_logger, printError
 from nuitka.tree.SourceReading import readSourceCodeFromFilename
 from nuitka.utils import Utils
 from nuitka.utils.AppDirs import getCacheDir
@@ -59,15 +60,18 @@ from nuitka.utils.FileOperations import (
     getFileContentByLine,
     getFileContents,
     getSubDirectories,
+    haveSameFileContents,
     isPathBelow,
     listDir,
     makePath,
+    putTextFileContents,
     withFileLock,
 )
 from nuitka.utils.ModuleNames import ModuleName
 from nuitka.utils.SharedLibraries import (
     callInstallNameTool,
     getPEFileInformation,
+    getPyWin32Dir,
     getWindowsDLLVersion,
     removeSxsFromDLL,
 )
@@ -102,7 +106,10 @@ def _detectedPrecompiledFile(filename, module_name, result, user_provided, techn
     if module_name in module_names:
         return
 
-    debug("Freezing module '%s' (from '%s').", module_name, filename)
+    if Options.isShowInclusion():
+        inclusion_logger.info(
+            "Freezing module '%s' (from '%s')." % (module_name, filename)
+        )
 
     uncompiled_module = makeUncompiledPythonModule(
         module_name=module_name,
@@ -155,14 +162,22 @@ __file__ = (__nuitka_binary_dir + '%s%s') if '__nuitka_binary_dir' in dict(__bui
             "def main():", "def main():return\n\nif 0:\n def _unused():"
         )
 
-    debug("Freezing module '%s' (from '%s').", module_name, filename)
+    if Options.isShowInclusion():
+        inclusion_logger.info(
+            "Freezing module '%s' (from '%s')." % (module_name, filename)
+        )
 
     is_package = os.path.basename(filename) == "__init__.py"
     source_code = Plugins.onFrozenModuleSourceCode(
         module_name=module_name, is_package=is_package, source_code=source_code
     )
 
-    bytecode = compile(source_code, filename, "exec", dont_inherit=True)
+    bytecode = compile(
+        source_code,
+        module_name.replace(".", os.path.sep) + ".py",
+        "exec",
+        dont_inherit=True,
+    )
 
     bytecode = Plugins.onFrozenModuleBytecode(
         module_name=module_name, is_package=is_package, bytecode=bytecode
@@ -253,15 +268,13 @@ def _detectImports(command, user_provided, technical):
 
     # Don't let errors here go unnoticed.
     if process.returncode != 0:
-        warning("There is a problem with detecting imports, CPython said:")
+        general.warning("There is a problem with detecting imports, CPython said:")
         for line in stderr.split(b"\n"):
-            Tracing.printError(line)
+            printError(line)
         sys.exit("Error, please report the issue with above output.")
 
     result = []
 
-    debug("Detecting imports:")
-
     detections = []
 
     for line in stderr.replace(b"\r", b"").split(b"\n"):
@@ -383,7 +396,7 @@ def scanStandardLibraryPath(stdlib_dir):
             if "ensurepip" in dirs:
                 dirs.remove("ensurepip")
 
-            # Ignore "lib-dynload" and "lib-tk" and alikes.
+            # Ignore "lib-dynload" and "lib-tk" and alike.
             dirs[:] = [
                 dirname
                 for dirname in dirs
@@ -453,23 +466,19 @@ def scanStandardLibraryPath(stdlib_dir):
 
 def _detectEarlyImports():
     encoding_names = [
-        filename[:-3]
-        for _path, filename in listDir(
-            os.path.dirname(sys.modules["encodings"].__file__)
-        )
-        if filename.endswith(".py")
-        if "__init__" not in filename
+        m[1] for m in pkgutil.iter_modules(sys.modules["encodings"].__path__)
     ]
 
     if os.name != "nt":
-        # On posix systems, and posix Python veriants on Windows, this won't
-        # work.
+        # On posix systems, and posix Python veriants on Windows, these won't
+        # work and fail to import.
         for encoding_name in ("mbcs", "cp65001", "oem"):
             if encoding_name in encoding_names:
                 encoding_names.remove(encoding_name)
 
     import_code = ";".join(
-        "import encodings.%s" % encoding_name for encoding_name in encoding_names
+        "import encodings.%s" % encoding_name
+        for encoding_name in sorted(encoding_names)
     )
 
     import_code += ";import locale;"
@@ -545,8 +554,6 @@ for imp in imports:
             if module.getFullName() not in early_names
         ]
 
-    debug("Finished detecting early imports.")
-
     return result
 
 
@@ -583,7 +590,7 @@ def _detectBinaryPathDLLsPosix(dll_filename):
 
         if _detected_python_rpath:
             _detected_python_rpath = _detected_python_rpath.replace(
-                b"$ORIGIN", os.path.dirname(sys.executable).encode("utf-8")
+                "$ORIGIN", os.path.dirname(sys.executable)
             )
 
     with withEnvironmentPathAdded("LD_LIBRARY_PATH", _detected_python_rpath):
@@ -593,6 +600,10 @@ def _detectBinaryPathDLLsPosix(dll_filename):
 
         stdout, _stderr = process.communicate()
 
+        inclusion_logger.debug(
+            "ldd output for %s is %s and %s" % (dll_filename, stdout, _stderr)
+        )
+
         for line in stdout.split(b"\n"):
             if not line:
                 continue
@@ -874,18 +885,7 @@ def _parseDependsExeOutput2(lines, result):
 
 
 def _parseDependsExeOutput(filename, result):
-    _parseDependsExeOutput2(getFileContentByLine(filename), result)
-
-
-def _getPyWin32Dir():
-    for path_element in sys.path:
-        if not path_element:
-            continue
-
-        candidate = os.path.join(path_element, "pywin32_system32")
-
-        if os.path.isdir(candidate):
-            return candidate
+    _parseDependsExeOutput2(getFileContentByLine(filename, encoding="latin1"), result)
 
 
 _scan_dir_cache = {}
@@ -919,7 +919,7 @@ def getScanDirectories(package_name, original_dir):
         and package_name is not None
         and package_name.isBelowNamespace("win32com")
     ):
-        pywin32_dir = _getPyWin32Dir()
+        pywin32_dir = getPyWin32Dir()
 
         if pywin32_dir is not None:
             scan_dirs.append(pywin32_dir)
@@ -993,7 +993,7 @@ def detectBinaryPathDLLsWindowsDependencyWalker(
             return result
 
     if Options.isShowProgress():
-        info("Analysing dependencies of '%s'." % binary_filename)
+        general.info("Analysing dependencies of '%s'." % binary_filename)
 
     scan_dirs = getScanDirectories(package_name, original_dir)
 
@@ -1053,9 +1053,7 @@ SxS
     deleteFile(dwp_filename, must_exist=True)
 
     if update_cache:
-        with open(cache_filename, "w") as cache_file:
-            for dll_filename in result:
-                print(dll_filename, file=cache_file)
+        putTextFileContents(filename=cache_filename, contents=result)
 
     return result
 
@@ -1094,7 +1092,7 @@ def _parsePEFileOutput(
         extracted = eval(getFileContents(cache_filename))
     else:
         if Options.isShowProgress():
-            info("Analysing dependencies of '%s'." % binary_filename)
+            general.info("Analysing dependencies of '%s'." % binary_filename)
 
         extracted = getPEFileInformation(binary_filename)
 
@@ -1203,10 +1201,10 @@ def detectBinaryDLLs(
     use_cache,
     update_cache,
 ):
-    """ Detect the DLLs used by a binary.
+    """Detect the DLLs used by a binary.
 
-        Using "ldd" (Linux), "pefile" or "depends.exe" (Windows), or
-        "otool" (macOS) the list of used DLLs is retrieved.
+    Using "ldd" (Linux), "pefile" or "depends.exe" (Windows), or
+    "otool" (macOS) the list of used DLLs is retrieved.
     """
 
     if (
@@ -1216,7 +1214,8 @@ def detectBinaryDLLs(
         return _detectBinaryPathDLLsPosix(dll_filename=original_filename)
     elif Utils.isWin32Windows() and Options.getWindowsDependencyTool() == "pefile":
         with TimerReport(
-            "Finding dependencies for %s took %%.2f seconds" % binary_filename
+            message="Finding dependencies for %s took %%.2f seconds" % binary_filename,
+            decider=Options.isShowProgress,
         ):
             return detectBinaryPathDLLsWindowsPE(
                 is_main_executable=is_main_executable,
@@ -1229,7 +1228,8 @@ def detectBinaryDLLs(
             )
     elif Utils.isWin32Windows():
         with TimerReport(
-            "Running depends.exe for %s took %%.2f seconds" % binary_filename
+            message="Running depends.exe for %s took %%.2f seconds" % binary_filename,
+            decider=Options.isShowProgress,
         ):
             return detectBinaryPathDLLsWindowsDependencyWalker(
                 is_main_executable=is_main_executable,
@@ -1269,10 +1269,8 @@ def detectUsedDLLs(source_dir, standalone_entry_points, use_cache, update_cache)
         for dll_filename in sorted(tuple(used_dlls)):
             if not os.path.isfile(dll_filename):
                 if _unfound_dlls:
-                    warning(
-                        """\
-Dependency '%s' could not be found, you might need to copy it
-manually."""
+                    general.warning(
+                        "Dependency '%s' could not be found, you might need to copy it manually."
                         % dll_filename
                     )
 
@@ -1287,17 +1285,15 @@ manually."""
     with ThreadPoolExecutor(max_workers=Utils.getCoreCount() * 3) as worker_pool:
         workers = []
 
-        for count, (original_filename, binary_filename, package_name) in enumerate(
-            standalone_entry_points
-        ):
+        for count, standalone_entry_point in enumerate(standalone_entry_points):
             workers.append(
                 worker_pool.submit(
                     addDLLInfo,
                     count,
                     source_dir,
-                    original_filename,
-                    binary_filename,
-                    package_name,
+                    standalone_entry_point.source_path,
+                    standalone_entry_point.dest_path,
+                    standalone_entry_point.package_name,
                 )
             )
 
@@ -1357,7 +1353,12 @@ def getSharedLibraryRPATH(filename):
 
     for line in stdout.split(b"\n"):
         if b"RPATH" in line or b"RUNPATH" in line:
-            return line[line.find(b"[") + 1 : line.rfind(b"]")]
+            result = line[line.find(b"[") + 1 : line.rfind(b"]")]
+
+            if str is not bytes:
+                result = result.decode("utf-8")
+
+            return result
 
     return None
 
@@ -1367,7 +1368,9 @@ def removeSharedLibraryRPATH(filename):
 
     if rpath is not None:
         if Options.isShowInclusion():
-            info("Removing 'RPATH' setting from '%s'.", filename)
+            inclusion_logger.info(
+                "Removing 'RPATH' setting '%s' from '%s'." % (rpath, filename)
+            )
 
         if not Utils.isExecutableCommand("chrpath"):
             sys.exit(
@@ -1390,6 +1393,16 @@ libraries that need to be removed."""
         assert retcode == 0, filename
 
 
+# These DLLs are run time DLLs from Microsoft, and packages will depend on different
+# ones, but it will be OK to use the latest one.
+ms_runtime_dlls = (
+    "msvcp140_1.dll",
+    "msvcp140.dll",
+    "vcruntime140_1.dll",
+    "concrt140.dll",
+)
+
+
 def copyUsedDLLs(source_dir, dist_dir, standalone_entry_points):
     # This is terribly complex, because we check the list of used DLLs
     # trying to avoid duplicates, and detecting errors with them not
@@ -1407,6 +1420,7 @@ def copyUsedDLLs(source_dir, dist_dir, standalone_entry_points):
     )
 
     removed_dlls = set()
+    warned_about = set()
 
     # Fist make checks and remove some.
     for dll_filename1, sources1 in tuple(iterItems(used_dlls)):
@@ -1434,17 +1448,14 @@ def copyUsedDLLs(source_dir, dist_dir, standalone_entry_points):
             dll_name = os.path.basename(dll_filename1)
 
             if Options.isShowInclusion():
-                info(
+                inclusion_logger.info(
                     """Colliding DLL names for %s, checking identity of \
 '%s' <-> '%s'."""
                     % (dll_name, dll_filename1, dll_filename2)
                 )
 
-            # Check that if a DLL has the same name, if it's identical,
-            # happens at least for OSC and Fedora 20.
-            import filecmp
-
-            if filecmp.cmp(dll_filename1, dll_filename2):
+            # Check that if a DLL has the same name, if it's identical, then it's easy.
+            if haveSameFileContents(dll_filename1, dll_filename2):
                 del used_dlls[dll_filename2]
                 removed_dlls.add(dll_filename2)
 
@@ -1469,15 +1480,20 @@ def copyUsedDLLs(source_dir, dist_dir, standalone_entry_points):
                     solved = False
 
                 if solved:
-                    warning(
-                        "Ignoring conflicting DLLs for '%s' and using newest file version."
-                        % dll_name
-                    )
+                    if dll_name not in warned_about and dll_name not in ms_runtime_dlls:
+                        warned_about.add(dll_name)
+
+                        inclusion_logger.warning(
+                            "Conflicting DLLs for '%s' in your installation, newest file version used, hoping for the best."
+                            % dll_name
+                        )
+
                     continue
 
-            # So we have conflicting DLLs, in which case we do not proceed.
-            warning(
-                """Ignoring non-identical DLLs for '%s'.
+            # So we have conflicting DLLs, in which case we do report the fact.
+            inclusion_logger.warning(
+                """\
+Ignoring non-identical DLLs for '%s'.
 %s used by:
    %s
 different from
@@ -1507,7 +1523,7 @@ different from
         dll_map.append((dll_filename, dll_name))
 
         if Options.isShowInclusion():
-            Tracing.general.info(
+            inclusion_logger.info(
                 "Included used shared library '%s' (used by %s)."
                 % (dll_filename, ", ".join(sources))
             )
@@ -1517,9 +1533,9 @@ different from
         # the relative DLL location in the ".dist" folder.
         for standalone_entry_point in standalone_entry_points:
             fixupBinaryDLLPathsMacOS(
-                binary_filename=standalone_entry_point[1],
+                binary_filename=standalone_entry_point.dest_path,
                 dll_map=dll_map,
-                original_location=standalone_entry_point[0],
+                original_location=standalone_entry_point.source_path,
             )
 
         for original_path, dll_filename in dll_map:
@@ -1533,7 +1549,7 @@ different from
         # For Linux, the "rpath" of libraries may be an issue and must be
         # removed.
         for standalone_entry_point in standalone_entry_points[1:]:
-            removeSharedLibraryRPATH(standalone_entry_point[1])
+            removeSharedLibraryRPATH(standalone_entry_point.dest_path)
 
         for _original_path, dll_filename in dll_map:
             removeSharedLibraryRPATH(os.path.join(dist_dir, dll_filename))
@@ -1541,14 +1557,14 @@ different from
         if python_version < 300:
             # For Win32, we might have to remove SXS paths
             for standalone_entry_point in standalone_entry_points[1:]:
-                removeSxsFromDLL(standalone_entry_point[1])
+                removeSxsFromDLL(standalone_entry_point.dest_path)
 
             for _original_path, dll_filename in dll_map:
                 removeSxsFromDLL(os.path.join(dist_dir, dll_filename))
 
 
 def copyDataFiles(dist_dir):
-    """ Copy the data files needed for standalone distribution.
+    """Copy the data files needed for standalone distribution.
 
     Args:
         dist_dir: The distribution folder under creation
