@@ -46,7 +46,7 @@ class NodeBase(NodeMetaClassBase):
     __slots__ = "parent", "source_ref"
 
     # Avoid the attribute unless it's really necessary.
-    if Options.isFullCompat():
+    if Options.is_fullcompat:
         __slots__ += ("effective_source_ref",)
 
     # String to identify the node class, to be consistent with its name.
@@ -75,32 +75,32 @@ class NodeBase(NodeMetaClassBase):
         return "<Node %s>" % (self.getDescription())
 
     def getDescription(self):
-        """ Description of the node, intended for use in __repr__ and
-            graphical display.
+        """Description of the node, intended for use in __repr__ and
+        graphical display.
 
         """
-        details = self.getDetails()
+        details = self.getDetailsForDisplay()
 
         if details:
-            return "'%s' with %s" % (self.kind, self.getDetails())
+            return "'%s' with %s" % (self.kind, details)
         else:
             return "'%s'" % self.kind
 
     def getDetails(self):
-        """ Details of the node, intended for re-creation.
+        """Details of the node, intended for re-creation.
 
-            We are not using the pickle mechanisms, but this is basically
-            part of what the constructor call needs. Real children will
-            also be added.
+        We are not using the pickle mechanisms, but this is basically
+        part of what the constructor call needs. Real children will
+        also be added.
 
         """
         # Virtual method, pylint: disable=no-self-use
         return {}
 
     def getDetailsForDisplay(self):
-        """ Details of the node, intended for use in __repr__ and dumps.
+        """Details of the node, intended for use in __repr__ and dumps.
 
-            This is also used for XML.
+        This is also used for XML.
         """
         return self.getDetails()
 
@@ -139,9 +139,7 @@ class NodeBase(NodeMetaClassBase):
         return result
 
     def getParent(self):
-        """ Parent of the node. Every node except modules have to have a parent.
-
-        """
+        """Parent of the node. Every node except modules have to have a parent."""
 
         if self.parent is None and not self.isCompiledPythonModule():
             # print self.getVisitableNodesNamed()
@@ -150,9 +148,7 @@ class NodeBase(NodeMetaClassBase):
         return self.parent
 
     def getChildName(self):
-        """ Return the role in the current parent, subject to changes.
-
-        """
+        """Return the role in the current parent, subject to changes."""
         parent = self.getParent()
 
         for key, value in parent.getVisitableNodesNamed():
@@ -178,9 +174,7 @@ class NodeBase(NodeMetaClassBase):
             return child_name
 
     def getParentFunction(self):
-        """ Return the parent that is a function.
-
-        """
+        """Return the parent that is a function."""
 
         parent = self.getParent()
 
@@ -190,9 +184,7 @@ class NodeBase(NodeMetaClassBase):
         return parent
 
     def getParentModule(self):
-        """ Return the parent that is module.
-
-        """
+        """Return the parent that is module."""
         parent = self
 
         while not parent.isCompiledPythonModule():
@@ -247,21 +239,21 @@ class NodeBase(NodeMetaClassBase):
         return self.source_ref
 
     def setCompatibleSourceReference(self, source_ref):
-        """ Bug compatible line numbers information.
+        """Bug compatible line numbers information.
 
-            As CPython outputs the last bit of bytecode executed, and not the
-            line of the operation. For example calls, output the line of the
-            last argument, as opposed to the line of the operation start.
+        As CPython outputs the last bit of bytecode executed, and not the
+        line of the operation. For example calls, output the line of the
+        last argument, as opposed to the line of the operation start.
 
-            For tests, we wants to be compatible. In improved more, we are
-            not being fully compatible, and just drop it altogether.
+        For tests, we wants to be compatible. In improved more, we are
+        not being fully compatible, and just drop it altogether.
         """
 
         # Getting the same source reference can be dealt with quickly, so do
         # this first.
         if (
             self.source_ref is not source_ref
-            and Options.isFullCompat()
+            and Options.is_fullcompat
             and self.source_ref != source_ref
         ):
             # An attribute outside of "__init__", so we save one memory for the
@@ -271,14 +263,14 @@ class NodeBase(NodeMetaClassBase):
             self.effective_source_ref = source_ref
 
     def getCompatibleSourceReference(self):
-        """ Bug compatible line numbers information.
+        """Bug compatible line numbers information.
 
-            See above.
+        See above.
         """
         return getattr(self, "effective_source_ref", self.source_ref)
 
     def asXml(self):
-        line = self.getSourceReference().getLineNumber()
+        line = self.source_ref.getLineNumber()
 
         result = TreeXML.Element("node", kind=self.__class__.__name__, line="%s" % line)
 
@@ -356,31 +348,28 @@ class NodeBase(NodeMetaClassBase):
     def isExpressionOperationInplace():
         return False
 
-    def isExpressionSideEffects(self):
-        # Virtual method, pylint: disable=no-self-use
-
-        # We need to provide this, as these node kinds are only imported if
-        # necessary, but we test against them.
+    @staticmethod
+    def isExpressionSideEffects():
         return False
 
-    def isExpressionMakeSequence(self):
-        # Virtual method, pylint: disable=no-self-use
+    @staticmethod
+    def isExpressionMakeSequence():
         return False
 
-    def isNumberConstant(self):
-        # Virtual method, pylint: disable=no-self-use
+    @staticmethod
+    def isNumberConstant():
         return False
 
-    def isExpressionCall(self):
-        # Virtual method, pylint: disable=no-self-use
+    @staticmethod
+    def isExpressionCall():
         return False
 
-    def isExpressionFunctionBodyBase(self):
-        # Virtual method, pylint: disable=no-self-use
+    @staticmethod
+    def isExpressionFunctionBodyBase():
         return False
 
-    def isExpressionOutlineFunctionBodyBase(self):
-        # Virtual method, pylint: disable=no-self-use
+    @staticmethod
+    def isExpressionOutlineFunctionBase():
         return False
 
     def visit(self, context, visitor):
@@ -389,26 +378,29 @@ class NodeBase(NodeMetaClassBase):
         for visitable in self.getVisitableNodes():
             visitable.visit(context, visitor)
 
-    def getVisitableNodes(self):
-        # Virtual method, pylint: disable=no-self-use
+    @staticmethod
+    def getVisitableNodes():
+
         return ()
 
-    def getVisitableNodesNamed(self):
-        """ Named children dictionary.
+    @staticmethod
+    def getVisitableNodesNamed():
+        """Named children dictionary.
 
-            For use in debugging and XML output.
+        For use in debugging and XML output.
         """
 
-        # Virtual method, pylint: disable=no-self-use
         return ()
 
-    def getName(self):
-        # Virtual method, pylint: disable=no-self-use
+    @staticmethod
+    def getName():
+        """ Name of the node if any. """
+
         return None
 
-    def mayHaveSideEffects(self):
+    @staticmethod
+    def mayHaveSideEffects():
         """ Unless we are told otherwise, everything may have a side effect. """
-        # Virtual method, pylint: disable=no-self-use
 
         return True
 
@@ -420,21 +412,24 @@ class NodeBase(NodeMetaClassBase):
 
         return (self,)
 
-    def mayRaiseException(self, exception_type):
+    @staticmethod
+    def mayRaiseException(exception_type):
         """ Unless we are told otherwise, everything may raise everything. """
-        # Virtual method, pylint: disable=no-self-use,unused-argument
+        # Virtual method, pylint: disable=unused-argument
 
         return True
 
-    def mayReturn(self):
-        return "_RETURN" in self.kind
-
-    def mayBreak(self):
-        # For overload, pylint: disable=no-self-use
+    @staticmethod
+    def mayReturn():
+        """ May this node do a return exit, to be overloaded for things that might. """
         return False
 
-    def mayContinue(self):
-        # For overload, pylint: disable=no-self-use
+    @staticmethod
+    def mayBreak():
+        return False
+
+    @staticmethod
+    def mayContinue():
         return False
 
     def needsFrame(self):
@@ -442,16 +437,15 @@ class NodeBase(NodeMetaClassBase):
 
         return self.mayRaiseException(BaseException)
 
-    def willRaiseException(self, exception_type):
+    @staticmethod
+    def willRaiseException(exception_type):
         """ Unless we are told otherwise, nothing may raise anything. """
-        # Virtual method, pylint: disable=no-self-use,unused-argument
-
+        # Virtual method, pylint: disable=unused-argument
         return False
 
-    def isStatementAborting(self):
+    @staticmethod
+    def isStatementAborting():
         """ Is the node aborting, control flow doesn't continue after this node.  """
-        assert self.isStatement(), self.kind
-
         return False
 
 
@@ -520,27 +514,23 @@ class ChildrenHavingMixin(object):
             if name in self.checkers:
                 value = self.checkers[name](value)
 
-            assert type(value) is not list, name
-
             if type(value) is tuple:
                 assert None not in value, name
 
                 for val in value:
                     val.parent = self
-            elif value is not None:
-                value.parent = self
             elif value is None:
                 pass
             else:
-                assert False, type(value)
+                value.parent = self
 
             attr_name = "subnode_" + name
             setattr(self, attr_name, value)
 
     def setChild(self, name, value):
-        """ Set a child value.
+        """Set a child value.
 
-            Do not overload, provider self.checkers instead.
+        Do not overload, provider self.checkers instead.
         """
         # Only accept legal child names
         assert name in self.named_children, name
@@ -611,9 +601,9 @@ class ChildrenHavingMixin(object):
         return tuple(result)
 
     def getVisitableNodesNamed(self):
-        """ Named children dictionary.
+        """Named children dictionary.
 
-            For use in debugging and XML output.
+        For use in debugging and XML output.
         """
         for name in self.named_children:
             attr_name = "subnode_" + name
@@ -693,9 +683,6 @@ class ClosureGiverNodeMixin(CodeNodeMixin):
     def __init__(self, name, code_prefix):
         CodeNodeMixin.__init__(self, name=name, code_prefix=code_prefix)
 
-        self.providing = {}
-        self.variable_order = []
-
         self.temp_variables = {}
 
         self.temp_scopes = {}
@@ -703,32 +690,18 @@ class ClosureGiverNodeMixin(CodeNodeMixin):
         self.preserver_id = 0
 
     def hasProvidedVariable(self, variable_name):
-        return variable_name in self.providing
+        return self.locals_scope.hasProvidedVariable(variable_name)
 
     def getProvidedVariable(self, variable_name):
-        if variable_name not in self.providing:
-            self.providing[variable_name] = self.createProvidedVariable(
-                variable_name=variable_name
-            )
-            self.variable_order.append(variable_name)
+        if not self.locals_scope.hasProvidedVariable(variable_name):
+            variable = self.createProvidedVariable(variable_name=variable_name)
+            self.locals_scope.registerProvidedVariable(variable)
 
-        return self.providing[variable_name]
+        return self.locals_scope.getProvidedVariable(variable_name)
 
+    @abstractmethod
     def createProvidedVariable(self, variable_name):
-        # Virtual method, pylint: disable=no-self-use
-        assert type(variable_name) is str
-
-        return None
-
-    def registerProvidedVariable(self, variable):
-        assert variable is not None
-
-        variable_name = variable.getName()
-        self.providing[variable_name] = variable
-        self.variable_order.append(variable_name)
-
-    def getProvidedVariableOrder(self):
-        return self.variable_order
+        """Create a variable provided by this function."""
 
     def allocateTempScope(self, name):
         self.temp_scopes[name] = self.temp_scopes.get(name, 0) + 1
@@ -851,24 +824,22 @@ class ClosureTakerMixin(object):
 
 
 class StatementBase(NodeBase):
-    """ Base class for all statements.
-
-    """
+    """Base class for all statements."""
 
     # Base classes can be abstract, pylint: disable=abstract-method
 
     # TODO: Have them all.
     # @abstractmethod
-    def getStatementNiceName(self):
-        # Virtual method, pylint: disable=no-self-use
+    @staticmethod
+    def getStatementNiceName():
         return "undescribed statement"
 
     def computeStatementSubExpressions(self, trace_collection):
-        """ Compute a statement.
+        """Compute a statement.
 
-            Default behavior is to just visit the child expressions first, and
-            then the node "computeStatement". For a few cases this needs to
-            be overloaded.
+        Default behavior is to just visit the child expressions first, and
+        then the node "computeStatement". For a few cases this needs to
+        be overloaded.
         """
         expressions = self.getVisitableNodes()
 
@@ -932,9 +903,9 @@ class StatementChildHavingBase(StatementBase):
         setattr(self, attr_name, value)
 
     def setChild(self, name, value):
-        """ Set a child value.
+        """Set a child value.
 
-            Do not overload, provider self.checkers instead.
+        Do not overload, provider self.checkers instead.
         """
         # Only accept legal child names
         assert name == self.named_child, name
@@ -998,9 +969,9 @@ class StatementChildHavingBase(StatementBase):
             raise AssertionError(self, "has illegal child", value, value.__class__)
 
     def getVisitableNodesNamed(self):
-        """ Named children dictionary.
+        """Named children dictionary.
 
-            For use in debugging and XML output.
+        For use in debugging and XML output.
         """
         attr_name = "subnode_" + self.named_child
         value = getattr(self, attr_name)
