@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -34,7 +34,6 @@ class StatementAssignmentSubscript(StatementChildrenHavingBase):
     named_children = ("source", "expression", "subscript")
     getSubscribed = StatementChildrenHavingBase.childGetter("expression")
     getSubscript = StatementChildrenHavingBase.childGetter("subscript")
-    getAssignSource = StatementChildrenHavingBase.childGetter("source")
 
     def __init__(self, expression, subscript, source, source_ref):
         StatementChildrenHavingBase.__init__(
@@ -54,11 +53,12 @@ class StatementAssignmentSubscript(StatementChildrenHavingBase):
         return self.getSubscribed().computeExpressionSetSubscript(
             set_node=self,
             subscript=self.getSubscript(),
-            value_node=self.getAssignSource(),
+            value_node=self.subnode_source,
             trace_collection=trace_collection,
         )
 
-    def getStatementNiceName(self):
+    @staticmethod
+    def getStatementNiceName():
         return "subscript assignment statement"
 
 
@@ -90,30 +90,30 @@ class StatementDelSubscript(StatementChildrenHavingBase):
             trace_collection=trace_collection,
         )
 
-    def getStatementNiceName(self):
+    @staticmethod
+    def getStatementNiceName():
         return "subscript del statement"
 
 
 class ExpressionSubscriptLookup(ExpressionChildrenHavingBase):
     kind = "EXPRESSION_SUBSCRIPT_LOOKUP"
 
-    named_children = ("subscribed", "subscript")
-    getLookupSource = ExpressionChildrenHavingBase.childGetter("subscribed")
-    getSubscript = ExpressionChildrenHavingBase.childGetter("subscript")
+    named_children = ("expression", "subscript")
 
-    def __init__(self, subscribed, subscript, source_ref):
+    def __init__(self, expression, subscript, source_ref):
         ExpressionChildrenHavingBase.__init__(
             self,
-            values={"subscribed": subscribed, "subscript": subscript},
+            values={"expression": expression, "subscript": subscript},
             source_ref=source_ref,
         )
 
     def computeExpression(self, trace_collection):
-        return self.getLookupSource().computeExpressionSubscript(
+        return self.subnode_expression.computeExpressionSubscript(
             lookup_node=self,
-            subscript=self.getSubscript(),
+            subscript=self.subnode_subscript,
             trace_collection=trace_collection,
         )
 
-    def isKnownToBeIterable(self, count):
+    @staticmethod
+    def isKnownToBeIterable(count):
         return None
